@@ -49,7 +49,8 @@
 #include <saAmf.h>
 #include <corosync/ipc_gen.h>
 #include <ipc_amf.h>
-#include <corosync/ais_util.h>
+#include <corosync/coroipcc.h>
+#include "util.h"
 
 
 struct res_overlay {
@@ -61,8 +62,7 @@ struct res_overlay {
  * Data structure for instance data
  */
 struct amfInstance {
-	int response_fd;
-	int dispatch_fd;
+	void *ipc_ctx;
 	SaAmfCallbacksT callbacks;
 	SaNameT compName;
 	int compRegistered;
@@ -131,12 +131,7 @@ saAmfInitialize (
 		goto error_destroy;
 	}
 
-	amfInstance->response_fd = -1;
-
-	amfInstance->dispatch_fd = -1;
-	
-	error = saServiceConnect (&amfInstance->response_fd,
-		&amfInstance->dispatch_fd, AMF_SERVICE);
+	error = coroipcc_service_connect (IPC_SOCKET_NAME, CPG_SERVICE, &amfInstance->ipc_ctx);
 	if (error != SA_AIS_OK) {
 		goto error_put_destroy;
 	}
@@ -172,7 +167,7 @@ saAmfSelectionObjectGet (
 		return (error);
 	}
 
-	*selectionObject = amfInstance->dispatch_fd;
+	*selectionObject = coroipcc_fd_get (amfInstance->ipc_ctx);
 
 	saHandleInstancePut (&amfHandleDatabase, amfHandle);
 	return (SA_AIS_OK);
@@ -184,7 +179,6 @@ saAmfDispatch (
 	SaAmfHandleT amfHandle,
 	SaDispatchFlagsT dispatchFlags)
 {
-	struct pollfd ufds;
 	int timeout = -1;
 	SaAisErrorT error;
 	int cont = 1; /* always continue do loop except when set to 0 */
@@ -219,17 +213,8 @@ saAmfDispatch (
 	}
 
 	do {
-		/*
-		 * Read data directly from socket
-		 */
-		ufds.fd = amfInstance->dispatch_fd;
-		ufds.events = POLLIN;
-		ufds.revents = 0;
-
-		error = saPollRetry (&ufds, 1, timeout);
-		if (error != SA_AIS_OK) {
-			goto error_put;
-		}
+		dispatch_avail = coroipcc_dispatch_recv (amfInstance->ipc_ctx,
+			(void *)&dispatch_data, timeout);
 
 		pthread_mutex_lock (&amfInstance->dispatch_mutex);
 
@@ -241,12 +226,6 @@ saAmfDispatch (
 			goto error_unlock;
 		}
 
-		if ((ufds.revents & (POLLERR|POLLHUP|POLLNVAL)) != 0) {
-			error = SA_AIS_ERR_BAD_HANDLE;
-			goto error_unlock;
-		}
-
-		dispatch_avail = ufds.revents & POLLIN;
 		if (dispatch_avail == 0 && dispatchFlags == SA_DISPATCH_ALL) {
 			pthread_mutex_unlock (&amfInstance->dispatch_mutex);
 			break; /* exit do while cont is 1 loop */
@@ -256,33 +235,6 @@ saAmfDispatch (
 			continue; /* next poll */
 		}
 
-		if (ufds.revents & POLLIN) {
-			/*
-			 * Queue empty, read response from socket
-			 */ 
-			error = saRecvRetry (amfInstance->dispatch_fd, &dispatch_data.header,
-				sizeof (mar_res_header_t));
-
-			if (error != SA_AIS_OK) {
-
-				goto error_unlock;
-			}
-			if (dispatch_data.header.size > sizeof (mar_res_header_t)) {
-
-				error = saRecvRetry (amfInstance->dispatch_fd, &dispatch_data.data,
-					dispatch_data.header.size - sizeof (mar_res_header_t));
-
-				if (error != SA_AIS_OK) {
-
-					goto error_unlock;
-				}
-			}
-		} else {
-			pthread_mutex_unlock (&amfInstance->dispatch_mutex);
-
-			continue;
-		}
-
 		/*
 		 * Make copy of callbacks, message data, unlock instance, and call callback
 		 * A risk of this dispatch method is that the callback routines may
@@ -439,21 +391,14 @@ saAmfFinalize (
 
 	amfInstance->finalize = 1;
 
+	coroipcc_service_disconnect (amfInstance->ipc_ctx);
+
 	pthread_mutex_unlock (&amfInstance->response_mutex);
 
 	pthread_mutex_unlock (&amfInstance->dispatch_mutex);
 
 	saHandleDestroy (&amfHandleDatabase, amfHandle);
 
-	if (amfInstance->response_fd != -1) {
-		shutdown (amfInstance->response_fd, 0);
-		close (amfInstance->response_fd);
-	}
-	if (amfInstance->dispatch_fd != -1) {
-		shutdown (amfInstance->dispatch_fd, 0);
-		close (amfInstance->dispatch_fd);
-	}
-
 	saHandleInstancePut (&amfHandleDatabase, amfHandle);
 
 	return (error);
@@ -469,6 +414,7 @@ saAmfComponentRegister (
 	SaAisErrorT error;
 	struct req_lib_amf_componentregister req_lib_amf_componentregister;
 	struct res_lib_amf_componentregister res_lib_amf_componentregister;
+	struct iovec iov;
 
 	error = saHandleInstanceGet (&amfHandleDatabase, amfHandle,
 		(void *)&amfInstance);
@@ -488,11 +434,13 @@ saAmfComponentRegister (
 			sizeof (SaNameT));
 	}
 
+	iov.iov_base = &req_lib_amf_componentregister;
+	iov.iov_len = sizeof (struct req_lib_amf_componentregister);
 	pthread_mutex_lock (&amfInstance->response_mutex);
 
-	error = saSendReceiveReply (amfInstance->response_fd,
-		&req_lib_amf_componentregister,
-		sizeof (struct req_lib_amf_componentregister),
+	error = coroipcc_msg_send_reply_receive (amfInstance->ipc_ctx,
+		&iov,
+		1,
 		&res_lib_amf_componentregister,
 		sizeof (struct res_lib_amf_componentregister));
 
@@ -517,6 +465,7 @@ saAmfComponentUnregister (
 	struct res_lib_amf_componentunregister res_lib_amf_componentunregister;
 	struct amfInstance *amfInstance;
 	SaAisErrorT error;
+	struct iovec iov;
 
 	error = saHandleInstanceGet (&amfHandleDatabase, amfHandle,
 		(void *)&amfInstance);
@@ -536,11 +485,14 @@ saAmfComponentUnregister (
 			sizeof (SaNameT));
 	}	
 
+	iov.iov_base = &req_lib_amf_componentunregister;
+	iov.iov_len = sizeof (struct req_lib_amf_componentunregister);
+
 	pthread_mutex_lock (&amfInstance->response_mutex);
 
-	error = saSendReceiveReply (amfInstance->response_fd,
-		&req_lib_amf_componentunregister,
-		sizeof (struct req_lib_amf_componentunregister),
+	error = coroipcc_msg_send_reply_receive (amfInstance->ipc_ctx,
+		&iov,
+		1,
 		&res_lib_amf_componentunregister,
 		sizeof (struct res_lib_amf_componentunregister));
 
@@ -601,6 +553,7 @@ saAmfPmStart (
 	struct res_lib_amf_pmstart res_lib_amf_pmstart;
 	struct amfInstance *amfInstance;
 	SaAisErrorT error;
+	struct iovec iov;
 
 	error = saHandleInstanceGet (&amfHandleDatabase, amfHandle,
 		(void *)&amfInstance);
@@ -617,11 +570,14 @@ saAmfPmStart (
 	req_lib_amf_pmstart.pmErrors = pmErrors;
 	req_lib_amf_pmstart.recommendedRecovery = recommendedRecovery;
 
+	iov.iov_base = &req_lib_amf_pmstart;
+	iov.iov_len = sizeof (struct req_lib_amf_pmstart);
+
 	pthread_mutex_lock (&amfInstance->response_mutex);
 
-	error = saSendReceiveReply (amfInstance->response_fd,
-		&req_lib_amf_pmstart,
-		sizeof (struct req_lib_amf_pmstart),
+	error = coroipcc_msg_send_reply_receive (amfInstance->ipc_ctx,
+		&iov,
+		1,
 		&res_lib_amf_pmstart,
 		sizeof (struct res_lib_amf_pmstart));
 
@@ -644,6 +600,7 @@ saAmfPmStop (
 	struct res_lib_amf_pmstop res_lib_amf_pmstop;
 	struct amfInstance *amfInstance;
 	SaAisErrorT error;
+	struct iovec iov;
 
 	error = saHandleInstanceGet (&amfHandleDatabase, amfHandle,
 		(void *)&amfInstance);
@@ -658,11 +615,14 @@ saAmfPmStop (
 	req_lib_amf_pmstop.processId = processId;
 	req_lib_amf_pmstop.pmErrors = pmErrors;
 
+	iov.iov_base = &req_lib_amf_pmstop;
+	iov.iov_len = sizeof (struct req_lib_amf_pmstop);
+
 	pthread_mutex_lock (&amfInstance->response_mutex);
 
-	error = saSendReceiveReply (amfInstance->response_fd,
-		&req_lib_amf_pmstop,
-		sizeof (struct req_lib_amf_pmstop),
+	error = coroipcc_msg_send_reply_receive (amfInstance->ipc_ctx,
+		&iov,
+		1,
 		&res_lib_amf_pmstop,
 		sizeof (struct res_lib_amf_pmstop));
 
@@ -686,6 +646,7 @@ saAmfHealthcheckStart (
 	struct res_lib_amf_healthcheckstart res_lib_amf_healthcheckstart;
 	struct amfInstance *amfInstance;
 	SaAisErrorT error;
+	struct iovec iov;
 
 	error = saHandleInstanceGet (&amfHandleDatabase, amfHandle,
 		(void *)&amfInstance);
@@ -702,11 +663,14 @@ saAmfHealthcheckStart (
 	req_lib_amf_healthcheckstart.invocationType = invocationType;
 	req_lib_amf_healthcheckstart.recommendedRecovery = recommendedRecovery;
 
+	iov.iov_base = &req_lib_amf_healthcheckstart;
+	iov.iov_len = sizeof (struct req_lib_amf_healthcheckstart);
+
 	pthread_mutex_lock (&amfInstance->response_mutex);
 
-	error = saSendReceiveReply (amfInstance->response_fd,
-		&req_lib_amf_healthcheckstart,
-		sizeof (struct req_lib_amf_healthcheckstart),
+	error = coroipcc_msg_send_reply_receive (amfInstance->ipc_ctx,
+		&iov,
+		1,
 		&res_lib_amf_healthcheckstart,
 		sizeof (struct res_lib_amf_healthcheckstart));
 
@@ -728,6 +692,7 @@ saAmfHealthcheckConfirm (
 	struct res_lib_amf_healthcheckconfirm res_lib_amf_healthcheckconfirm;
 	struct amfInstance *amfInstance;
 	SaAisErrorT error;
+	struct iovec iov;
 
 	error = saHandleInstanceGet (&amfHandleDatabase, amfHandle,
 		(void *)&amfInstance);
@@ -743,11 +708,14 @@ saAmfHealthcheckConfirm (
 		healthcheckKey, sizeof (SaAmfHealthcheckKeyT));
 	req_lib_amf_healthcheckconfirm.healthcheckResult = healthcheckResult;
 
+	iov.iov_base = &req_lib_amf_healthcheckconfirm;
+	iov.iov_len = sizeof (struct req_lib_amf_healthcheckconfirm);
+
 	pthread_mutex_lock (&amfInstance->response_mutex);
 
-	error = saSendReceiveReply (amfInstance->response_fd,
-		&req_lib_amf_healthcheckconfirm,
-		sizeof (struct req_lib_amf_healthcheckconfirm),
+	error = coroipcc_msg_send_reply_receive (amfInstance->ipc_ctx,
+		&iov,
+		1,
 		&res_lib_amf_healthcheckconfirm,
 		sizeof (struct res_lib_amf_healthcheckconfirm));
 
@@ -767,6 +735,7 @@ saAmfHealthcheckStop (
 	struct req_lib_amf_healthcheckstop req_lib_amf_healthcheckstop;
 	struct res_lib_amf_healthcheckstop res_lib_amf_healthcheckstop;
 	struct amfInstance *amfInstance;
+	struct iovec iov;
 	SaAisErrorT error;
 
 	error = saHandleInstanceGet (&amfHandleDatabase, amfHandle,
@@ -782,11 +751,14 @@ saAmfHealthcheckStop (
 	memcpy (&req_lib_amf_healthcheckstop.healthcheckKey,
 		healthcheckKey, sizeof (SaAmfHealthcheckKeyT));
 
+	iov.iov_base = &req_lib_amf_healthcheckstop;
+	iov.iov_len = sizeof (struct req_lib_amf_healthcheckstop);
+
 	pthread_mutex_lock (&amfInstance->response_mutex);
 
-	error = saSendReceiveReply (amfInstance->response_fd,
-		&req_lib_amf_healthcheckstop,
-		sizeof (struct req_lib_amf_healthcheckstop),
+	error = coroipcc_msg_send_reply_receive (amfInstance->ipc_ctx,
+		&iov,
+		1,
 		&res_lib_amf_healthcheckstop,
 		sizeof (struct res_lib_amf_healthcheckstop));
 
@@ -808,6 +780,7 @@ saAmfHAStateGet (
 	struct amfInstance *amfInstance;
 	struct req_lib_amf_hastateget req_lib_amf_hastateget;
 	struct res_lib_amf_hastateget res_lib_amf_hastateget;
+	struct iovec iov;
 	SaAisErrorT error;
 
 	error = saHandleInstanceGet (&amfHandleDatabase, amfHandle,
@@ -816,6 +789,9 @@ saAmfHAStateGet (
 		return (error);
 	}
 
+	iov.iov_base = &req_lib_amf_hastateget,
+	iov.iov_len = sizeof (struct req_lib_amf_hastateget),
+
 	pthread_mutex_lock (&amfInstance->response_mutex);
 
 	req_lib_amf_hastateget.header.id = MESSAGE_REQ_AMF_HASTATEGET;
@@ -823,9 +799,11 @@ saAmfHAStateGet (
 	memcpy (&req_lib_amf_hastateget.compName, compName, sizeof (SaNameT));
 	memcpy (&req_lib_amf_hastateget.csiName, csiName, sizeof (SaNameT));
 
-	error = saSendReceiveReply (amfInstance->response_fd,
-		&req_lib_amf_hastateget, sizeof (struct req_lib_amf_hastateget),
-		&res_lib_amf_hastateget, sizeof (struct res_lib_amf_hastateget));
+	error = coroipcc_msg_send_reply_receive (amfInstance->ipc_ctx,
+		&iov,
+		1,
+		&res_lib_amf_hastateget,
+		sizeof (struct res_lib_amf_hastateget));
 
 	pthread_mutex_unlock (&amfInstance->response_mutex);
 
@@ -847,6 +825,7 @@ saAmfCSIQuiescingComplete (
 	struct req_lib_amf_csiquiescingcomplete req_lib_amf_csiquiescingcomplete;
 	struct res_lib_amf_csiquiescingcomplete res_lib_amf_csiquiescingcomplete;
 	struct amfInstance *amfInstance;
+	struct iovec iov;
 	SaAisErrorT errorResult;
 
 	error = saHandleInstanceGet (&amfHandleDatabase, amfHandle,
@@ -860,11 +839,14 @@ saAmfCSIQuiescingComplete (
 	req_lib_amf_csiquiescingcomplete.invocation = invocation;
 	req_lib_amf_csiquiescingcomplete.error = error;
 
+	iov.iov_base = &req_lib_amf_csiquiescingcomplete;
+	iov.iov_len = sizeof (struct req_lib_amf_csiquiescingcomplete);
+
 	pthread_mutex_lock (&amfInstance->response_mutex);
 
-	errorResult = saSendReceiveReply (amfInstance->response_fd,
-		&req_lib_amf_csiquiescingcomplete,
-		sizeof (struct req_lib_amf_csiquiescingcomplete),
+	errorResult = coroipcc_msg_send_reply_receive (amfInstance->ipc_ctx,
+		&iov,
+		1,
 		&res_lib_amf_csiquiescingcomplete,
 		sizeof (struct res_lib_amf_csiquiescingcomplete));
 
@@ -885,6 +867,7 @@ saAmfProtectionGroupTrack (
 	struct amfInstance *amfInstance;
 	struct req_lib_amf_protectiongrouptrack req_lib_amf_protectiongrouptrack;
 	struct res_lib_amf_protectiongrouptrack res_lib_amf_protectiongrouptrack;
+	struct iovec iov;
 	SaAisErrorT error;
 
 	req_lib_amf_protectiongrouptrack.header.size = sizeof (struct req_lib_amf_protectiongrouptrack);
@@ -900,11 +883,14 @@ saAmfProtectionGroupTrack (
 		return (error);
 	}
 
+	iov.iov_base = &req_lib_amf_protectiongrouptrack;
+	iov.iov_len = sizeof (struct req_lib_amf_protectiongrouptrack);
+
 	pthread_mutex_lock (&amfInstance->response_mutex);
 
-	error = saSendReceiveReply (amfInstance->response_fd,
-		&req_lib_amf_protectiongrouptrack,
-		sizeof (struct req_lib_amf_protectiongrouptrack),
+	error = coroipcc_msg_send_reply_receive (amfInstance->ipc_ctx,
+		&iov,
+		1,
 		&res_lib_amf_protectiongrouptrack,
 		sizeof (struct res_lib_amf_protectiongrouptrack));
 
@@ -923,6 +909,7 @@ saAmfProtectionGroupTrackStop (
 	struct amfInstance *amfInstance;
 	struct req_lib_amf_protectiongrouptrackstop req_lib_amf_protectiongrouptrackstop;
 	struct res_lib_amf_protectiongrouptrackstop res_lib_amf_protectiongrouptrackstop;
+	struct iovec iov;
 	SaAisErrorT error;
 
 	error = saHandleInstanceGet (&amfHandleDatabase, amfHandle,
@@ -935,11 +922,13 @@ saAmfProtectionGroupTrackStop (
 	req_lib_amf_protectiongrouptrackstop.header.id = MESSAGE_REQ_AMF_PROTECTIONGROUPTRACKSTOP;
 	memcpy (&req_lib_amf_protectiongrouptrackstop.csiName, csiName, sizeof (SaNameT));
 
+	iov.iov_base = &req_lib_amf_protectiongrouptrackstop,
+	iov.iov_len = sizeof (struct req_lib_amf_protectiongrouptrackstop),
 	pthread_mutex_lock (&amfInstance->response_mutex);
 
-	error = saSendReceiveReply (amfInstance->response_fd,
-		&req_lib_amf_protectiongrouptrackstop,
-		sizeof (struct req_lib_amf_protectiongrouptrackstop),
+	error = coroipcc_msg_send_reply_receive (amfInstance->ipc_ctx,
+		&iov,
+		1,
 		&res_lib_amf_protectiongrouptrackstop,
 		sizeof (struct res_lib_amf_protectiongrouptrackstop));
 
@@ -961,6 +950,7 @@ saAmfComponentErrorReport (
 	struct amfInstance *amfInstance;
 	struct req_lib_amf_componenterrorreport req_lib_amf_componenterrorreport;
 	struct res_lib_amf_componenterrorreport res_lib_amf_componenterrorreport;
+	struct iovec iov;
 	SaAisErrorT error;
 
 	error = saHandleInstanceGet (&amfHandleDatabase, amfHandle,
@@ -975,13 +965,16 @@ saAmfComponentErrorReport (
 		sizeof (SaNameT));
 	req_lib_amf_componenterrorreport.errorDetectionTime = errorDetectionTime;
 	req_lib_amf_componenterrorreport.recommendedRecovery = recommendedRecovery;
-    DPRINT (("start error report\n"));
-	error = saSendReceiveReply (amfInstance->response_fd,
-		&req_lib_amf_componenterrorreport,
-		sizeof (struct req_lib_amf_componenterrorreport),
+
+	iov.iov_base = &req_lib_amf_componenterrorreport;
+	iov.iov_len = sizeof (struct req_lib_amf_componenterrorreport);
+
+	error = coroipcc_msg_send_reply_receive (amfInstance->ipc_ctx,
+		&iov,
+		1,
 		&res_lib_amf_componenterrorreport,
 		sizeof (struct res_lib_amf_componenterrorreport));
-    DPRINT (("end error report\n"));
+
 
 	error = res_lib_amf_componenterrorreport.header.error;
 
@@ -1001,6 +994,7 @@ saAmfComponentErrorClear (
 	struct amfInstance *amfInstance;
 	struct req_lib_amf_componenterrorclear req_lib_amf_componenterrorclear;
 	struct res_lib_amf_componenterrorclear res_lib_amf_componenterrorclear;
+	struct iovec iov;
 	SaAisErrorT error;
 
 	error = saHandleInstanceGet (&amfHandleDatabase, amfHandle,
@@ -1013,9 +1007,14 @@ saAmfComponentErrorClear (
 	req_lib_amf_componenterrorclear.header.size = sizeof (struct req_lib_amf_componenterrorclear);
 	memcpy (&req_lib_amf_componenterrorclear.compName, compName, sizeof (SaNameT));
 
-	error = saSendReceiveReply (amfInstance->response_fd,
-		&req_lib_amf_componenterrorclear,
-		sizeof (struct req_lib_amf_componenterrorclear),
+	iov.iov_base = &req_lib_amf_componenterrorclear;
+	iov.iov_len = sizeof (struct req_lib_amf_componenterrorclear);
+
+	pthread_mutex_lock (&amfInstance->response_mutex);
+
+	error = coroipcc_msg_send_reply_receive (amfInstance->ipc_ctx,
+		&iov,
+		1,
 		&res_lib_amf_componenterrorclear,
 		sizeof (struct res_lib_amf_componenterrorclear));
 
@@ -1035,6 +1034,7 @@ saAmfResponse (
 	struct amfInstance *amfInstance;
 	struct req_lib_amf_response req_lib_amf_response;
 	struct res_lib_amf_response res_lib_amf_response;
+	struct iovec iov;
 	SaAisErrorT errorResult;
 
 	errorResult = saHandleInstanceGet (&amfHandleDatabase, amfHandle,
@@ -1048,11 +1048,16 @@ saAmfResponse (
 	req_lib_amf_response.invocation = invocation;
 	req_lib_amf_response.error = error;
 
+	iov.iov_base = &req_lib_amf_response;
+	iov.iov_len = sizeof (struct req_lib_amf_response);
+
 	pthread_mutex_lock (&amfInstance->response_mutex);
 
-	errorResult = saSendReceiveReply (amfInstance->response_fd,
-		&req_lib_amf_response, sizeof (struct req_lib_amf_response),
-		&res_lib_amf_response, sizeof (struct res_lib_amf_response));
+	errorResult = coroipcc_msg_send_reply_receive (amfInstance->ipc_ctx,
+		&iov,
+		1,
+		&res_lib_amf_response,
+		sizeof (struct res_lib_amf_response));
 
 	pthread_mutex_unlock (&amfInstance->response_mutex);
 
