@@ -52,6 +52,7 @@
 #include <saAis.h>
 #include <saClm.h>
 #include <ipc_clm.h>
+#include <corosync/coroipcc.h>
 #include "../include/mar_clm.h"
 
 #include "util.h"
@@ -62,8 +63,7 @@ struct res_overlay {
 };
 
 struct clmInstance {
-	int response_fd;
-	int dispatch_fd;
+	void *ipc_ctx;
 	SaClmCallbacksT callbacks;
 	int finalize;
 	pthread_mutex_t response_mutex;
@@ -171,12 +171,7 @@ saClmInitialize (
 		goto error_destroy;
 	}
 
-	clmInstance->response_fd = -1;
-
-	clmInstance->dispatch_fd = -1;
-
-	error = saServiceConnect (&clmInstance->response_fd,
-		&clmInstance->dispatch_fd, CLM_SERVICE);
+	error = coroipcc_service_connect (IPC_SOCKET_NAME, CLM_SERVICE, &clmInstance->ipc_ctx);
 	if (error != SA_AIS_OK) {
 		goto error_put_destroy;
 	}
@@ -242,7 +237,7 @@ saClmSelectionObjectGet (
 		return (error);
 	}
 
-	*selectionObject = clmInstance->dispatch_fd;
+	*selectionObject = coroipcc_fd_get (clmInstance->ipc_ctx);
 
 	saHandleInstancePut (&clmHandleDatabase, clmHandle);
 	return (SA_AIS_OK);
@@ -269,7 +264,6 @@ saClmDispatch (
 	SaClmHandleT clmHandle,
 	SaDispatchFlagsT dispatchFlags)
 {
-	struct pollfd ufds;
 	int timeout = -1;
 	SaAisErrorT error;
 	int cont = 1; /* always continue do loop except when set to 0 */
@@ -307,65 +301,35 @@ saClmDispatch (
 	}
 
 	do {
-		ufds.fd = clmInstance->dispatch_fd;
-		ufds.events = POLLIN;
-		ufds.revents = 0;
-
 		pthread_mutex_lock (&clmInstance->dispatch_mutex);
 
-		error = saPollRetry (&ufds, 1, timeout);
-		if (error != SA_AIS_OK) {
-			goto error_unlock;
-		}
+		dispatch_avail = coroipcc_dispatch_recv (clmInstance->ipc_ctx,
+			(void *)&dispatch_data, timeout);
 
-		/*
-		 * Handle has been finalized in another thread
-		 */
-		if (clmInstance->finalize == 1) {
-			error = SA_AIS_OK;
-			goto error_unlock;
-		}
+		pthread_mutex_unlock (&clmInstance->dispatch_mutex);
 
-		if ((ufds.revents & (POLLERR|POLLHUP|POLLNVAL)) != 0) {
-			error = SA_AIS_ERR_BAD_HANDLE;
-			goto error_unlock;
-		}
-
-		dispatch_avail = ufds.revents & POLLIN;
 		if (dispatch_avail == 0 && dispatchFlags == SA_DISPATCH_ALL) {
-			pthread_mutex_unlock (&clmInstance->dispatch_mutex);
 			break; /* exit do while cont is 1 loop */
 		} else
 		if (dispatch_avail == 0) {
-			pthread_mutex_unlock (&clmInstance->dispatch_mutex);
 			continue; /* next poll */
 		}
 
-		if (ufds.revents & POLLIN) {
-			error = saRecvRetry (clmInstance->dispatch_fd, &dispatch_data.header,
-				sizeof (mar_res_header_t));
-			if (error != SA_AIS_OK) {
-				goto error_unlock;
+		if (dispatch_avail == -1) {
+			if (clmInstance->finalize == 1) {
+				error = SA_AIS_OK;
+			} else {
+				error = SA_AIS_ERR_LIBRARY;
 			}
-			if (dispatch_data.header.size > sizeof (mar_res_header_t)) {
-				error = saRecvRetry (clmInstance->dispatch_fd, &dispatch_data.data,
-					dispatch_data.header.size - sizeof (mar_res_header_t));
-				if (error != SA_AIS_OK) {
-					goto error_unlock;
-				}
-			}
-		} else {
-			pthread_mutex_unlock (&clmInstance->dispatch_mutex);
-			continue;
+			goto error_put;
 		}
-			
+
 		/*
 		 * Make copy of callbacks, message data, unlock instance, and call callback
 		 * A risk of this dispatch method is that the callback routines may
 		 * operate at the same time that clmFinalize has been called in another thread.
 		 */
 		memcpy (&callbacks, &clmInstance->callbacks, sizeof (SaClmCallbacksT));
-		pthread_mutex_unlock (&clmInstance->dispatch_mutex);
 
 		/*
 		 * Dispatch incoming message
@@ -440,9 +404,6 @@ saClmDispatch (
 
 	goto error_put;
 
-error_unlock:
-	pthread_mutex_unlock (&clmInstance->dispatch_mutex);
-
 error_put:
 	saHandleInstancePut (&clmHandleDatabase, clmHandle);
 	return (error);
@@ -498,19 +459,12 @@ saClmFinalize (
 
 	clmInstance->finalize = 1;
 
+	coroipcc_service_disconnect (clmInstance->ipc_ctx);
+
 	pthread_mutex_unlock (&clmInstance->response_mutex);
 
 	saHandleDestroy (&clmHandleDatabase, clmHandle);
 
-	if (clmInstance->response_fd != -1) {
-		shutdown (clmInstance->response_fd, 0);
-		close (clmInstance->response_fd);
-	}
-	if (clmInstance->dispatch_fd != -1) {
-		shutdown (clmInstance->dispatch_fd, 0);
-		close (clmInstance->dispatch_fd);
-	}
-
 	saHandleInstancePut (&clmHandleDatabase, clmHandle);
 
 	return (error);
@@ -528,6 +482,7 @@ saClmClusterTrack (
 	SaAisErrorT error = SA_AIS_OK;
 	int items_to_copy;
 	unsigned int i;
+	struct iovec iov;
 
 	error = saHandleInstanceGet (&clmHandleDatabase, clmHandle,
 		(void *)&clmInstance);
@@ -561,6 +516,9 @@ saClmClusterTrack (
 		req_lib_clm_clustertrack.return_in_callback = 1;
 	}
 
+	iov.iov_base = &req_lib_clm_clustertrack;
+	iov.iov_len = sizeof (req_lib_clm_clustertrack);;
+
 	pthread_mutex_lock (&clmInstance->response_mutex);
 
 	if ((clmInstance->callbacks.saClmClusterTrackCallback == 0) &&
@@ -571,9 +529,9 @@ saClmClusterTrack (
 		goto error_exit;
 	}
 
-	error = saSendReceiveReply (clmInstance->response_fd,
-		&req_lib_clm_clustertrack,
-		sizeof (struct req_lib_clm_clustertrack),
+	error = coroipcc_msg_send_reply_receive (clmInstance->ipc_ctx,
+		&iov,
+		1,
 		&res_lib_clm_clustertrack,
 		sizeof (struct res_lib_clm_clustertrack));
 
@@ -621,6 +579,7 @@ saClmClusterTrackStop (
 	struct req_lib_clm_trackstop req_lib_clm_trackstop;
 	struct res_lib_clm_trackstop res_lib_clm_trackstop;
 	SaAisErrorT error = SA_AIS_OK;
+	struct iovec iov;
 
 	req_lib_clm_trackstop.header.size = sizeof (struct req_lib_clm_trackstop);
 	req_lib_clm_trackstop.header.id = MESSAGE_REQ_CLM_TRACKSTOP;
@@ -630,11 +589,14 @@ saClmClusterTrackStop (
 		return (error);
 	}
 
+	iov.iov_base = &req_lib_clm_trackstop;
+	iov.iov_len = sizeof (struct req_lib_clm_trackstop);
+
 	pthread_mutex_lock (&clmInstance->response_mutex);
 
-	error = saSendReceiveReply (clmInstance->response_fd,
-		&req_lib_clm_trackstop,
-		sizeof (struct req_lib_clm_trackstop),
+	error = coroipcc_msg_send_reply_receive (clmInstance->ipc_ctx,
+		&iov,
+		1,
 		&res_lib_clm_trackstop,
 		sizeof (struct res_lib_clm_trackstop));
 
@@ -656,6 +618,7 @@ saClmClusterNodeGet (
 	struct req_lib_clm_nodeget req_lib_clm_nodeget;
 	struct res_clm_nodeget res_clm_nodeget;
 	SaAisErrorT error = SA_AIS_OK;
+	struct iovec iov;
 
 	if (clusterNode == NULL) {
 		return (SA_AIS_ERR_INVALID_PARAM);
@@ -671,6 +634,9 @@ saClmClusterNodeGet (
 		return (error);
 	}
 
+	iov.iov_base = &req_lib_clm_nodeget,
+	iov.iov_len = sizeof (struct req_lib_clm_nodeget),
+
 	pthread_mutex_lock (&clmInstance->response_mutex);
 
 	/*
@@ -680,8 +646,11 @@ saClmClusterNodeGet (
 	req_lib_clm_nodeget.header.id = MESSAGE_REQ_CLM_NODEGET;
 	req_lib_clm_nodeget.node_id = nodeId;
 
-	error = saSendReceiveReply (clmInstance->response_fd, &req_lib_clm_nodeget,
-		sizeof (struct req_lib_clm_nodeget), &res_clm_nodeget, sizeof (res_clm_nodeget));
+	error = coroipcc_msg_send_reply_receive (clmInstance->ipc_ctx,
+		&iov,
+		1,
+		&res_clm_nodeget,
+		sizeof (res_clm_nodeget));
 	if (error != SA_AIS_OK) {
 		goto error_exit;
 	}
@@ -708,6 +677,7 @@ saClmClusterNodeGetAsync (
 	struct clmInstance *clmInstance;
 	struct req_lib_clm_nodegetasync req_lib_clm_nodegetasync;
 	struct res_clm_nodegetasync res_clm_nodegetasync;
+	struct iovec iov;
 	SaAisErrorT error = SA_AIS_OK;
 
 	req_lib_clm_nodegetasync.header.size = sizeof (struct req_lib_clm_nodegetasync);
@@ -728,9 +698,15 @@ saClmClusterNodeGetAsync (
 		goto error_exit;
 	}
 
-	error = saSendReceiveReply (clmInstance->response_fd, &req_lib_clm_nodegetasync,
-		sizeof (struct req_lib_clm_nodegetasync),
-		&res_clm_nodegetasync, sizeof (struct res_clm_nodegetasync));
+	iov.iov_base = &req_lib_clm_nodegetasync;
+	iov.iov_len = sizeof (req_lib_clm_nodegetasync);
+
+	error = coroipcc_msg_send_reply_receive (
+		clmInstance->ipc_ctx,
+		&iov,
+		1,
+		&res_clm_nodegetasync,
+		sizeof (struct res_clm_nodegetasync));
 	if (error != SA_AIS_OK) {
 		goto error_exit;
 	}
