@@ -46,24 +46,25 @@
 #include <sys/un.h>
 
 #include <saAis.h>
+#include <corosync/coroipcc.h>
 #include <corosync/list.h>
 #include <saLck.h>
 #include <corosync/ipc_gen.h>
-#include "../include/ipc_lck.h"
+#include "ipc_lck.h"
+#include "mar_sa.h"
 
 #include "util.h"
 
 struct message_overlay {
 	mar_res_header_t header __attribute__((aligned(8)));
-	char data[4096];
+	char data[256000];
 };
 
 /*
  * Data structure for instance data
  */
 struct lckInstance {
-	int response_fd;
-	int dispatch_fd;
+	void *ipc_ctx;
 	SaLckCallbacksT callbacks;
 	int finalize;
 	SaLckHandleT lckHandle;
@@ -73,7 +74,7 @@ struct lckInstance {
 };
 
 struct lckResourceInstance {
-	int response_fd;
+	void *ipc_ctx;
 	SaLckHandleT lckHandle;
 	SaLckResourceHandleT lckResourceHandle;
 	SaLckResourceOpenFlagsT resourceOpenFlags;
@@ -84,7 +85,7 @@ struct lckResourceInstance {
 };
 
 struct lckLockIdInstance {
-	int response_fd;
+	void *ipc_ctx;
 	SaLckResourceHandleT lckResourceHandle;
 	struct list_head list;
 	void *resource_lock;
@@ -261,10 +262,7 @@ saLckInitialize (
 		goto error_destroy;
 	}
 
-	lckInstance->response_fd = -1;
-
-	error = saServiceConnect (&lckInstance->response_fd,
-		&lckInstance->dispatch_fd, LCK_SERVICE);
+	error = coroipcc_service_connect (IPC_SOCKET_NAME, LCK_SERVICE, &lckInstance->ipc_ctx);
 	if (error != SA_AIS_OK) {
 		goto error_put_destroy;
 	}
@@ -281,7 +279,6 @@ saLckInitialize (
 
 	pthread_mutex_init (&lckInstance->response_mutex, NULL);
 
-
 	saHandleInstancePut (&lckHandleDatabase, *lckHandle);
 
 	return (SA_AIS_OK);
@@ -310,7 +307,7 @@ saLckSelectionObjectGet (
 		return (error);
 	}
 
-	*selectionObject = lckInstance->dispatch_fd;
+	*selectionObject = coroipcc_fd_get (lckInstance->ipc_ctx);
 
 	saHandleInstancePut (&lckHandleDatabase, lckHandle);
 
@@ -330,8 +327,6 @@ saLckDispatch (
 	const SaLckHandleT lckHandle,
 	SaDispatchFlagsT dispatchFlags)
 {
-	struct pollfd ufds;
-	int poll_fd;
 	int timeout = 1;
 	SaLckCallbacksT callbacks;
 	SaAisErrorT error;
@@ -368,18 +363,9 @@ saLckDispatch (
 	}
 
 	do {
-		/*
-		 * Read data directly from socket
-		 */
-		poll_fd = lckInstance->dispatch_fd;
-		ufds.fd = poll_fd;
-		ufds.events = POLLIN;
-		ufds.revents = 0;
+		dispatch_avail = coroipcc_dispatch_recv (lckInstance->ipc_ctx,
+			(void *)&dispatch_data, timeout);
 
-		error = saPollRetry(&ufds, 1, timeout);
-		if (error != SA_AIS_OK) {
-			goto error_put;
-		}
 		pthread_mutex_lock(&lckInstance->dispatch_mutex);
 
 		if (lckInstance->finalize == 1) {
@@ -387,13 +373,6 @@ saLckDispatch (
 			goto error_unlock;
 		}
 
-		if ((ufds.revents & (POLLERR|POLLHUP|POLLNVAL)) != 0) {
-				error = SA_AIS_ERR_BAD_HANDLE;
-				goto error_unlock;
-		}
-		
-		dispatch_avail = (ufds.revents & POLLIN);
-
 		if (dispatch_avail == 0 && dispatchFlags == SA_DISPATCH_ALL) {
 			pthread_mutex_unlock(&lckInstance->dispatch_mutex);
 			break; /* exit do while cont is 1 loop */
@@ -403,19 +382,6 @@ saLckDispatch (
 			continue;
 		}
 		
-		memset(&dispatch_data,0, sizeof(struct message_overlay));
-		error = saRecvRetry (lckInstance->dispatch_fd, &dispatch_data.header, sizeof (mar_res_header_t));
-		if (error != SA_AIS_OK) {
-			goto error_unlock;
-		}
-		if (dispatch_data.header.size > sizeof (mar_res_header_t)) {
-			error = saRecvRetry (lckInstance->dispatch_fd, &dispatch_data.data,
-				dispatch_data.header.size - sizeof (mar_res_header_t));
-			if (error != SA_AIS_OK) {
-				goto error_unlock;
-			}
-		}
-
 		/*
 		* Make copy of callbacks, message data, unlock instance,
 		* and call callback. A risk of this dispatch method is that
@@ -526,10 +492,10 @@ saLckDispatch (
 				res_lib_lck_resourceunlockasync->invocation,
 				res_lib_lck_resourceunlockasync->header.error);
 
-			if (res_lib_lck_resourcelockasync->header.error == SA_AIS_OK) {
+			if (res_lib_lck_resourceunlockasync->header.error == SA_AIS_OK) {
 				error = saHandleInstanceGet (&lckLockIdHandleDatabase,
-							     res_lib_lck_resourceunlockasync->lockId,
-							     (void *)&lckLockIdInstance);
+				     res_lib_lck_resourceunlockasync->lockId,
+				     (void *)&lckLockIdInstance);
 				if (error == SA_AIS_OK) {
 					saHandleInstancePut (&lckLockIdHandleDatabase, res_lib_lck_resourceunlockasync->lockId);
 
@@ -571,7 +537,6 @@ saLckDispatch (
 	} while (cont);
 error_unlock:
 	pthread_mutex_unlock(&lckInstance->dispatch_mutex);
-error_put:
 	saHandleInstancePut(&lckHandleDatabase, lckHandle);
 error_exit:
 	return (error);
@@ -603,20 +568,12 @@ saLckFinalize (
 
 	lckInstance->finalize = 1;
 
+	coroipcc_service_disconnect (lckInstance->ipc_ctx);
+
 	pthread_mutex_unlock (&lckInstance->response_mutex);
 
 // TODO	lckInstanceFinalize (lckInstance);
 
-	if (lckInstance->response_fd != -1) {
-		shutdown (lckInstance->response_fd, 0);
-		close (lckInstance->response_fd);
-	}
-
-	if (lckInstance->dispatch_fd != -1) {
-		shutdown (lckInstance->dispatch_fd, 0);
-		close (lckInstance->dispatch_fd);
-	}
-
 	saHandleInstancePut (&lckHandleDatabase, lckHandle);
 
 	return (SA_AIS_OK);
@@ -633,6 +590,7 @@ saLckResourceOpen (
 	SaAisErrorT error;
 	struct lckResourceInstance *lckResourceInstance;
 	struct lckInstance *lckInstance;
+	struct iovec iov;
 	struct req_lib_lck_resourceopen req_lib_lck_resourceopen;
 	struct res_lib_lck_resourceopen res_lib_lck_resourceopen;
 
@@ -662,7 +620,7 @@ saLckResourceOpen (
 		goto error_destroy;
 	}
 
-	lckResourceInstance->response_fd = lckInstance->response_fd;
+	lckResourceInstance->ipc_ctx = lckInstance->ipc_ctx;
 
 	lckResourceInstance->lckHandle = lckHandle;
 	lckResourceInstance->lckResourceHandle = *lckResourceHandle;
@@ -671,18 +629,22 @@ saLckResourceOpen (
 	req_lib_lck_resourceopen.header.size = sizeof (struct req_lib_lck_resourceopen);
 	req_lib_lck_resourceopen.header.id = MESSAGE_REQ_LCK_RESOURCEOPEN;
 
-	marshall_to_mar_name_t (&req_lib_lck_resourceopen.lockResourceName, (SaNameT *)lockResourceName);
+	marshall_SaNameT_to_mar_name_t (&req_lib_lck_resourceopen.lockResourceName, (SaNameT *)lockResourceName);
 
 	memcpy (&lckResourceInstance->lockResourceName, lockResourceName, sizeof(SaNameT));
 	req_lib_lck_resourceopen.resourceOpenFlags = resourceOpenFlags;
 	req_lib_lck_resourceopen.resourceHandle = *lckResourceHandle;
 	req_lib_lck_resourceopen.async_call = 0;
 
+	iov.iov_base = &req_lib_lck_resourceopen;
+	iov.iov_len = sizeof (struct req_lib_lck_resourceopen);
+
 	pthread_mutex_lock (&lckInstance->response_mutex);
 
-	error = saSendReceiveReply (lckResourceInstance->response_fd, 
-		&req_lib_lck_resourceopen,
-		sizeof (struct req_lib_lck_resourceopen),
+	error = coroipcc_msg_send_reply_receive (
+		lckResourceInstance->ipc_ctx, 
+		&iov,
+		1,
 		&res_lib_lck_resourceopen,
 		sizeof (struct res_lib_lck_resourceopen));
 	
@@ -726,6 +688,7 @@ saLckResourceOpenAsync (
 	struct lckResourceInstance *lckResourceInstance;
 	struct lckInstance *lckInstance;
 	SaLckResourceHandleT lckResourceHandle;
+	struct iovec iov;
 	SaAisErrorT error;
 	struct req_lib_lck_resourceopen req_lib_lck_resourceopen;
 	struct res_lib_lck_resourceopenasync res_lib_lck_resourceopenasync;
@@ -753,13 +716,13 @@ saLckResourceOpenAsync (
 		goto error_destroy;
 	}
 
-	lckResourceInstance->response_fd = lckInstance->response_fd;
+	lckResourceInstance->ipc_ctx = lckInstance->ipc_ctx;
 	lckResourceInstance->response_mutex = &lckInstance->response_mutex;
 	lckResourceInstance->lckHandle = lckHandle;
 	lckResourceInstance->lckResourceHandle = lckResourceHandle;
 	lckResourceInstance->resourceOpenFlags = resourceOpenFlags;
 
-	marshall_to_mar_name_t (&req_lib_lck_resourceopen.lockResourceName, 
+	marshall_SaNameT_to_mar_name_t (&req_lib_lck_resourceopen.lockResourceName, 
 			(SaNameT *)lockResourceName);
 	memcpy (&lckResourceInstance->lockResourceName, lockResourceName, sizeof (SaNameT));
 	req_lib_lck_resourceopen.header.size = sizeof (struct req_lib_lck_resourceopen);
@@ -769,11 +732,15 @@ saLckResourceOpenAsync (
 	req_lib_lck_resourceopen.resourceHandle = lckResourceHandle;
 	req_lib_lck_resourceopen.async_call = 1;
 
+	iov.iov_base = &req_lib_lck_resourceopen;
+	iov.iov_len = sizeof (struct req_lib_lck_resourceopen);
+
 	pthread_mutex_lock (&lckInstance->response_mutex);
 
-	error = saSendReceiveReply (lckResourceInstance->response_fd, 
-		&req_lib_lck_resourceopen,
-		sizeof (struct req_lib_lck_resourceopen),
+	error = coroipcc_msg_send_reply_receive (
+		lckResourceInstance->ipc_ctx, 
+		&iov,
+		1,
 		&res_lib_lck_resourceopenasync,
 		sizeof (struct res_lib_lck_resourceopenasync));
 
@@ -801,6 +768,7 @@ saLckResourceClose (
 {
 	struct req_lib_lck_resourceclose req_lib_lck_resourceclose;
 	struct res_lib_lck_resourceclose res_lib_lck_resourceclose;
+	struct iovec iov;
 	SaAisErrorT error;
 	struct lckResourceInstance *lckResourceInstance;
 
@@ -812,15 +780,19 @@ saLckResourceClose (
 
 	req_lib_lck_resourceclose.header.size = sizeof (struct req_lib_lck_resourceclose);
 	req_lib_lck_resourceclose.header.id = MESSAGE_REQ_LCK_RESOURCECLOSE;
-	marshall_to_mar_name_t (&req_lib_lck_resourceclose.lockResourceName,
+	marshall_SaNameT_to_mar_name_t (&req_lib_lck_resourceclose.lockResourceName,
 		&lckResourceInstance->lockResourceName);
 	req_lib_lck_resourceclose.resourceHandle = lckResourceHandle;
 
+	iov.iov_base = &req_lib_lck_resourceclose;
+	iov.iov_len = sizeof (struct req_lib_lck_resourceclose);
+
 	pthread_mutex_lock (lckResourceInstance->response_mutex);
 
-	error = saSendReceiveReply (lckResourceInstance->response_fd, 
-		&req_lib_lck_resourceclose,
-		sizeof (struct req_lib_lck_resourceclose),
+	error = coroipcc_msg_send_reply_receive (
+		lckResourceInstance->ipc_ctx, 
+		&iov,
+		1,
 		&res_lib_lck_resourceclose,
 		sizeof (struct res_lib_lck_resourceclose));
 
@@ -845,11 +817,11 @@ saLckResourceLock (
 {
 	struct req_lib_lck_resourcelock req_lib_lck_resourcelock;
 	struct res_lib_lck_resourcelock res_lib_lck_resourcelock;
+	struct iovec iov;
 	SaAisErrorT error;
 	struct lckResourceInstance *lckResourceInstance;
 	struct lckLockIdInstance *lckLockIdInstance;
-	int lock_fd;
-	int dummy_fd;
+	void *lock_ctx;
 
 	error = saHandleInstanceGet (&lckResourceHandleDatabase, lckResourceHandle,
 		(void *)&lckResourceInstance);
@@ -869,18 +841,18 @@ saLckResourceLock (
 		goto error_destroy;
 	}
 
-	error = saServiceConnect (&lock_fd, &dummy_fd, LCK_SERVICE);
+	error = coroipcc_service_connect (IPC_SOCKET_NAME, LCK_SERVICE, &lock_ctx);
 	if (error != SA_AIS_OK) { // TODO error handling
 		goto error_destroy;
 	}
 
 	lckLockIdInstance->response_mutex = lckResourceInstance->response_mutex;
-	lckLockIdInstance->response_fd = lckResourceInstance->response_fd;
+	lckLockIdInstance->ipc_ctx = lckResourceInstance->ipc_ctx;
 	lckLockIdInstance->lckResourceHandle = lckResourceHandle;
 
 	req_lib_lck_resourcelock.header.size = sizeof (struct req_lib_lck_resourcelock);
 	req_lib_lck_resourcelock.header.id = MESSAGE_REQ_LCK_RESOURCELOCK;
-	marshall_to_mar_name_t (&req_lib_lck_resourcelock.lockResourceName,
+	marshall_SaNameT_to_mar_name_t (&req_lib_lck_resourcelock.lockResourceName,
 		&lckResourceInstance->lockResourceName);
 	req_lib_lck_resourcelock.lockMode = lockMode;
 	req_lib_lck_resourcelock.lockFlags = lockFlags;
@@ -894,18 +866,18 @@ saLckResourceLock (
 		&lckResourceInstance->source,
 		sizeof (mar_message_source_t));
 
+	iov.iov_base = &req_lib_lck_resourcelock;	
+	iov.iov_len = sizeof (struct req_lib_lck_resourcelock);
+
 	/*
 	 * no mutex needed here since its a new connection
 	 */
-	error = saSendReceiveReply (lock_fd, 
-		&req_lib_lck_resourcelock,
-		sizeof (struct req_lib_lck_resourcelock),
+	error = coroipcc_msg_send_reply_receive (lock_ctx, 
+		&iov,
+		1,
 		&res_lib_lck_resourcelock,
 		sizeof (struct res_lib_lck_resourcelock));
 
-	close (lock_fd);
-	close (dummy_fd);
-
 	if (error == SA_AIS_OK) {
 		lckLockIdInstance->resource_lock = res_lib_lck_resourcelock.resource_lock;
 		*lockStatus = res_lib_lck_resourcelock.lockStatus;
@@ -938,11 +910,11 @@ saLckResourceLockAsync (
 {
 	struct req_lib_lck_resourcelock req_lib_lck_resourcelock;
 	struct res_lib_lck_resourcelockasync res_lib_lck_resourcelockasync;
+	struct iovec iov;
 	SaAisErrorT error;
 	struct lckResourceInstance *lckResourceInstance;
 	struct lckLockIdInstance *lckLockIdInstance;
-	int lock_fd;
-	int dummy_fd;
+	void *lock_ctx;
 
 	error = saHandleInstanceGet (&lckResourceHandleDatabase, lckResourceHandle,
 		(void *)&lckResourceInstance);
@@ -962,18 +934,18 @@ saLckResourceLockAsync (
 		goto error_destroy;
 	}
 
-	error = saServiceConnect (&lock_fd, &dummy_fd, LCK_SERVICE);
+	error = coroipcc_service_connect (IPC_SOCKET_NAME, LCK_SERVICE, &lock_ctx);
 	if (error != SA_AIS_OK) { // TODO error handling
 		goto error_destroy;
 	}
 
 	lckLockIdInstance->response_mutex = lckResourceInstance->response_mutex;
-	lckLockIdInstance->response_fd = lckResourceInstance->response_fd;
+	lckLockIdInstance->ipc_ctx = lckResourceInstance->ipc_ctx;
 	lckLockIdInstance->lckResourceHandle = lckResourceHandle;
 
 	req_lib_lck_resourcelock.header.size = sizeof (struct req_lib_lck_resourcelock);
 	req_lib_lck_resourcelock.header.id = MESSAGE_REQ_LCK_RESOURCELOCKASYNC;
-	marshall_to_mar_name_t (&req_lib_lck_resourcelock.lockResourceName,
+	marshall_SaNameT_to_mar_name_t (&req_lib_lck_resourcelock.lockResourceName,
 		&lckResourceInstance->lockResourceName);
 	req_lib_lck_resourcelock.lockMode = lockMode;
 	req_lib_lck_resourcelock.lockFlags = lockFlags;
@@ -987,18 +959,19 @@ saLckResourceLockAsync (
 		&lckResourceInstance->source,
 		sizeof (mar_message_source_t));
 
+	iov.iov_base = &req_lib_lck_resourcelock;
+	iov.iov_len = sizeof (struct req_lib_lck_resourcelock);
+
 	/*
 	 * no mutex needed here since its a new connection
 	 */
-	error = saSendReceiveReply (lock_fd, 
-		&req_lib_lck_resourcelock,
-		sizeof (struct req_lib_lck_resourcelock),
+	error = coroipcc_msg_send_reply_receive (
+		lock_ctx, 
+		&iov,
+		1,
 		&res_lib_lck_resourcelockasync,
 		sizeof (struct res_lib_lck_resourcelock));
 
-	close (lock_fd);
-	close (dummy_fd);
-
 	if (error == SA_AIS_OK) {
 		return (res_lib_lck_resourcelockasync.header.error);
 	}
@@ -1023,6 +996,7 @@ saLckResourceUnlock (
 {
 	struct req_lib_lck_resourceunlock req_lib_lck_resourceunlock;
 	struct res_lib_lck_resourceunlock res_lib_lck_resourceunlock;
+	struct iovec iov;
 	SaAisErrorT error;
 	struct lckLockIdInstance *lckLockIdInstance;
 	struct lckResourceInstance *lckResourceInstance;
@@ -1043,7 +1017,7 @@ saLckResourceUnlock (
 		return (error);
 	}
 
-	marshall_to_mar_name_t (&req_lib_lck_resourceunlock.lockResourceName,
+	marshall_SaNameT_to_mar_name_t (&req_lib_lck_resourceunlock.lockResourceName,
 		&lckResourceInstance->lockResourceName);
 
 	saHandleInstancePut (&lckResourceHandleDatabase,
@@ -1057,11 +1031,15 @@ saLckResourceUnlock (
 	req_lib_lck_resourceunlock.async_call = 0;
 	req_lib_lck_resourceunlock.resource_lock = lckLockIdInstance->resource_lock;
 
+	iov.iov_base = &req_lib_lck_resourceunlock;
+	iov.iov_len = sizeof (struct req_lib_lck_resourceunlock);
+
 	pthread_mutex_lock (lckLockIdInstance->response_mutex);
 
-	error = saSendReceiveReply (lckLockIdInstance->response_fd, 
-		&req_lib_lck_resourceunlock,
-		sizeof (struct req_lib_lck_resourceunlock),
+	error = coroipcc_msg_send_reply_receive (
+		lckLockIdInstance->ipc_ctx, 
+		&iov,
+		1,
 		&res_lib_lck_resourceunlock,
 		sizeof (struct res_lib_lck_resourceunlock));
 
@@ -1081,6 +1059,7 @@ saLckResourceUnlockAsync (
 {
 	struct req_lib_lck_resourceunlock req_lib_lck_resourceunlock;
 	struct res_lib_lck_resourceunlockasync res_lib_lck_resourceunlockasync;
+	struct iovec iov;
 	SaAisErrorT error;
 	struct lckLockIdInstance *lckLockIdInstance;
 	struct lckResourceInstance *lckResourceInstance;
@@ -1101,7 +1080,7 @@ saLckResourceUnlockAsync (
 		return (error);
 	}
 
-	marshall_to_mar_name_t (&req_lib_lck_resourceunlock.lockResourceName,
+	marshall_SaNameT_to_mar_name_t (&req_lib_lck_resourceunlock.lockResourceName,
 		&lckResourceInstance->lockResourceName);
 
 	saHandleInstancePut (&lckResourceHandleDatabase,
@@ -1117,11 +1096,14 @@ saLckResourceUnlockAsync (
 	req_lib_lck_resourceunlock.lockId = lockId;
 	req_lib_lck_resourceunlock.async_call = 1;
 
+	iov.iov_base = &req_lib_lck_resourceunlock;
+	iov.iov_len = sizeof (struct req_lib_lck_resourceunlock);
+
 	pthread_mutex_lock (lckLockIdInstance->response_mutex);
 
-	error = saSendReceiveReply (lckLockIdInstance->response_fd, 
-		&req_lib_lck_resourceunlock,
-		sizeof (struct req_lib_lck_resourceunlock),
+	error = coroipcc_msg_send_reply_receive (lckLockIdInstance->ipc_ctx, 
+		&iov,
+		1,
 		&res_lib_lck_resourceunlockasync,
 		sizeof (struct res_lib_lck_resourceunlockasync));
 
@@ -1138,6 +1120,7 @@ saLckLockPurge (
 {
 	struct req_lib_lck_lockpurge req_lib_lck_lockpurge;
 	struct res_lib_lck_lockpurge res_lib_lck_lockpurge;
+	struct iovec iov;
 	SaAisErrorT error;
 	struct lckResourceInstance *lckResourceInstance;
 
@@ -1149,14 +1132,17 @@ saLckLockPurge (
 
 	req_lib_lck_lockpurge.header.size = sizeof (struct req_lib_lck_lockpurge);
 	req_lib_lck_lockpurge.header.id = MESSAGE_REQ_LCK_LOCKPURGE;
-	marshall_to_mar_name_t (&req_lib_lck_lockpurge.lockResourceName,
+	marshall_SaNameT_to_mar_name_t (&req_lib_lck_lockpurge.lockResourceName,
 		&lckResourceInstance->lockResourceName);
 
+	iov.iov_base = &req_lib_lck_lockpurge;
+	iov.iov_len = sizeof (struct req_lib_lck_lockpurge);
+
 	pthread_mutex_lock (lckResourceInstance->response_mutex);
 
-	error = saSendReceiveReply (lckResourceInstance->response_fd, 
-		&req_lib_lck_lockpurge,
-		sizeof (struct req_lib_lck_lockpurge),
+	error = coroipcc_msg_send_reply_receive (lckResourceInstance->ipc_ctx, 
+		&iov,
+		1,
 		&res_lib_lck_lockpurge,
 		sizeof (struct res_lib_lck_lockpurge));
 
