@@ -594,7 +594,7 @@ static void nodeids_init (void)
 	int i;
 	amf_node_t *amf_node;
 
-	ENTER ("");
+	ENTER ();
 
 	if (amf_cluster == NULL) {
 		return;
@@ -611,7 +611,7 @@ static void nodeids_init (void)
 			if (strcmp ((char*)amf_node->saAmfNodeClmNode.value,
 				clm_node_list[i].hostname) == 0) {
 
-				dprintf ("%s id set to %u", amf_node->name.value,
+				TRACE1 ("%s id set to %u", amf_node->name.value,
 					clm_node_list[i].nodeid);
 				amf_node->nodeid = clm_node_list[i].nodeid;
 			}
@@ -680,7 +680,7 @@ static int mcast_sync_data (
 	res = api->totem_mcast (iov, 2, TOTEM_AGREED);
 
 	if (res != 0) {
-		dprintf("Unable to send %d bytes of sync data\n", req_exec.header.size);
+		TRACE1("Unable to send %d bytes of sync data\n", req_exec.header.size);
 	}
 
 	return res;
@@ -1111,7 +1111,7 @@ static void cluster_joined_nodes_start (void)
 	int i;
 	struct amf_node *node;
 
-	ENTER ("");
+	ENTER ();
 	log_printf(LOG_NOTICE, "AMF synchronisation ready, starting cluster");
 
 	for (i = 0; i < clm_node_list_entries; i++) {
@@ -1150,7 +1150,7 @@ static void amf_sync_init (void)
 			}
 			break;
 		default:
-			dprintf ("unknown state: %u", scsm.state);;
+			TRACE1 ("unknown state: %u", scsm.state);;
 			assert (0);
 			break;
 	}
@@ -1287,7 +1287,7 @@ static void amf_sync_activate (void)
 		case NORMAL_OPERATION:
 			break;
 		default:
-			dprintf ("unknown state: %u", scsm.state);;
+			TRACE1 ("unknown state: %u", scsm.state);;
 			assert (0);
 			break;
 	}
@@ -1338,9 +1338,7 @@ static void amf_confchg_fn (
 	unsigned int *joined_list, int joined_list_entries,
 	struct memb_ring_id *ring_id)
 {
-	ENTER ("mnum: %d, jnum: %d, lnum: %d, sync state: %s, ring ID %llu rep %s\n",
-		member_list_entries, joined_list_entries, left_list_entries,
-		scsm_state_names[scsm.state], ring_id->seq, api->totem_ip_print (&ring_id->rep));
+	ENTER ();
 
 	switch (scsm.state) {
 		case UNCONFIGURED:
@@ -1442,7 +1440,7 @@ static int amf_lib_exit_fn (void *conn)
 	/* Make sure this is not a new connection */
 	if (comp != NULL && comp->conn == conn ) {
 		comp->conn = NULL;
-		dprintf ("Lib exit from comp %s\n", getSaNameT (&comp->name));
+		TRACE1 ("Lib exit from comp %s\n", getSaNameT (&comp->name));
 	}
 
 	return (0);
@@ -1493,7 +1491,7 @@ static void message_handler_req_exec_amf_comp_register (
 		res_lib.header.size = sizeof (struct res_lib_amf_componentregister);
 		res_lib.header.error = error;
 
-		api->ipc_conn_send_response (
+		api->ipc_response_send (
 			comp->conn, &res_lib, sizeof (struct res_lib_amf_componentregister));
 	}
 }
@@ -1571,7 +1569,7 @@ static void message_handler_req_exec_amf_clc_cleanup_completed (
 	}
 
 	comp = amf_comp_find (amf_cluster, &req_exec->compName);
-	ENTER ("%s",comp->name.value);
+	ENTER ();
 
 	if (comp == NULL) {
 		log_printf (LOG_ERR, "Error: '%s' not found", req_exec->compName.value);
@@ -1603,7 +1601,7 @@ static void message_handler_req_exec_amf_healthcheck_tmo (
 		return;
 	}
 
-	ENTER ("%s", comp->name.value);
+	ENTER ();
 
 	healthcheck = amf_comp_find_healthcheck (comp, &req_exec->safHealthcheckKey);
 
@@ -1633,7 +1631,7 @@ static void message_handler_req_exec_amf_response (
 		res_lib.header.id = MESSAGE_RES_AMF_RESPONSE;
 		res_lib.header.size = sizeof (struct res_lib_amf_response);
 		res_lib.header.error = retval;
-		api->ipc_conn_send_response (comp->conn, &res_lib, sizeof (res_lib));
+		api->ipc_response_send (comp->conn, &res_lib, sizeof (res_lib));
 	}
 }
 
@@ -1678,7 +1676,7 @@ static void message_handler_req_exec_amf_sync_start (
 		case UNCONFIGURED:
 			break;
 		default:
-			dprintf ("unknown state %d", scsm.state);
+			TRACE1 ("unknown state %d", scsm.state);
 			assert (0);
 			break;
 	}
@@ -1788,7 +1786,7 @@ static void message_handler_req_exec_amf_sync_data (
 					 scsm.csi_attribute->name);
 			break;
 		default:
-			dprintf ("unknown object: %u", req_exec->object_type);
+			TRACE1 ("unknown object: %u", req_exec->object_type);
 			assert (0);
 			break;
 	}
@@ -1871,7 +1869,7 @@ static void message_handler_req_lib_amf_componentregister (
 		res_lib.header.id = MESSAGE_RES_AMF_COMPONENTREGISTER;
 		res_lib.header.size = sizeof (struct res_lib_amf_componentregister);
 		res_lib.header.error = SA_AIS_ERR_INVALID_PARAM;
-		api->ipc_conn_send_response (
+		api->ipc_response_send (
 			conn, &res_lib, sizeof (struct res_lib_amf_componentregister));
 	}
 }
@@ -1943,7 +1941,7 @@ static void message_handler_req_lib_amf_pmstart (
 	res_lib.header.id = MESSAGE_RES_AMF_PMSTART;
 	res_lib.header.size = sizeof (res_lib);
 	res_lib.header.error = error;
-	api->ipc_conn_send_response (conn, &res_lib,
+	api->ipc_response_send (conn, &res_lib,
 								sizeof (struct res_lib_amf_pmstart));
 
 }
@@ -1981,7 +1979,7 @@ static void message_handler_req_lib_amf_pmstop (
 	res_lib.header.id = MESSAGE_RES_AMF_PMSTOP;
 	res_lib.header.size = sizeof (res_lib);
 	res_lib.header.error = error;
-	api->ipc_conn_send_response (conn, &res_lib,
+	api->ipc_response_send (conn, &res_lib,
 								sizeof (struct res_lib_amf_pmstop));
 
 }
@@ -2010,7 +2008,7 @@ static void message_handler_req_lib_amf_healthcheckstart (
 	res_lib.header.id = MESSAGE_RES_AMF_HEALTHCHECKSTART;
 	res_lib.header.size = sizeof (res_lib);
 	res_lib.header.error = error;
-	api->ipc_conn_send_response (conn, &res_lib,
+	api->ipc_response_send (conn, &res_lib,
 		sizeof (struct res_lib_amf_healthcheckstart));
 }
 
@@ -2035,7 +2033,7 @@ static void message_handler_req_lib_amf_healthcheckconfirm (
 	res_lib.header.id = MESSAGE_RES_AMF_HEALTHCHECKCONFIRM;
 	res_lib.header.size = sizeof (res_lib);
 	res_lib.header.error = error;
-	api->ipc_conn_send_response (conn, &res_lib, sizeof (res_lib));
+	api->ipc_response_send (conn, &res_lib, sizeof (res_lib));
 }
 
 static void message_handler_req_lib_amf_healthcheckstop (
@@ -2058,7 +2056,7 @@ static void message_handler_req_lib_amf_healthcheckstop (
 	res_lib.header.id = MESSAGE_RES_AMF_HEALTHCHECKSTOP;
 	res_lib.header.size = sizeof (res_lib);
 	res_lib.header.error = error;
-	api->ipc_conn_send_response (conn, &res_lib, sizeof (res_lib));
+	api->ipc_response_send (conn, &res_lib, sizeof (res_lib));
 }
 
 static void message_handler_req_lib_amf_hastateget (void *conn, void *msg)
@@ -2084,7 +2082,7 @@ static void message_handler_req_lib_amf_hastateget (void *conn, void *msg)
 	res_lib.header.size = sizeof (struct res_lib_amf_hastateget);
 	res_lib.header.error = error;
 
-	api->ipc_conn_send_response (conn, &res_lib,
+	api->ipc_response_send (conn, &res_lib,
 		sizeof (struct res_lib_amf_hastateget));
 }
 
@@ -2140,7 +2138,7 @@ static void message_handler_req_lib_amf_protectiongrouptrack (
 	if (amfProtectionGroup) {
 		res_lib_amf_protectiongrouptrack.header.error = SA_AIS_OK;
 	}
-	api->ipc_conn_send_response (conn, &res_lib_amf_protectiongrouptrack,
+	api->ipc_response_send (conn, &res_lib_amf_protectiongrouptrack,
 		sizeof (struct res_lib_amf_protectiongrouptrack));
 
 	if (amfProtectionGroup &&
@@ -2200,7 +2198,7 @@ static void message_handler_req_lib_amf_protectiongrouptrackstop (
 	if (track) {
 		res_lib_amf_protectiongrouptrackstop.header.error = SA_AIS_OK;
 	}
-	api->ipc_conn_send_response (conn, &res_lib_amf_protectiongrouptrackstop,
+	api->ipc_response_send (conn, &res_lib_amf_protectiongrouptrackstop,
 		sizeof (struct res_lib_amf_protectiongrouptrackstop));
 
 #endif
@@ -2284,7 +2282,7 @@ static void message_handler_req_lib_amf_componenterrorreport (
 		res_lib.header.size = sizeof (struct res_lib_amf_componenterrorreport);
 		res_lib.header.id = MESSAGE_RES_AMF_COMPONENTERRORREPORT;
 		res_lib.header.error = SA_AIS_ERR_NOT_EXIST;
-		api->ipc_conn_send_response (conn, &res_lib,
+		api->ipc_response_send (conn, &res_lib,
 			sizeof (struct res_lib_amf_componenterrorreport));
 	}
 }
@@ -2344,7 +2342,7 @@ static void message_handler_req_lib_amf_response (void *conn, void *msg)
 {
 	struct res_lib_amf_response res_lib;
 	struct req_lib_amf_response *req_lib = msg;
-	int multicast, send_ok;
+	int multicast;
 	SaAisErrorT retval;
 	SaUint32T interface;
 	SaNameT dn;
@@ -2377,25 +2375,14 @@ static void message_handler_req_lib_amf_response (void *conn, void *msg)
 		req_exec.error = req_lib->error;
 		iovec.iov_base = (char *)&req_exec;
 		iovec.iov_len = sizeof (req_exec);
-		send_ok = api->totem_send_ok (&iovec, 1);
-
-		if (send_ok) {
-			if (api->totem_mcast (&iovec, 1, TOTEM_AGREED) == 0) {
-				goto end;
-			} else {
-				corosync_fatal_error (COROSYNC_FATAL_ERR);
-			}
-		} else {
-			/* TOTEM queue is full, try again later */
-			retval = SA_AIS_ERR_TRY_AGAIN;
-		}
+		assert (api->totem_mcast (&iovec, 1, TOTEM_AGREED) == 0);
 	}
 
 send_response:
 	res_lib.header.id = MESSAGE_RES_AMF_RESPONSE;
 	res_lib.header.size = sizeof (struct res_lib_amf_response);
 	res_lib.header.error = retval;
-	api->ipc_conn_send_response (conn, &res_lib, sizeof (res_lib));
+	api->ipc_response_send (conn, &res_lib, sizeof (res_lib));
 end:
 	return;
 }
